$!								2-JUN-1994
$!
$! This command procedure runs the http_server.exe image and must reside
$! in the same directory.  It takes the following parameters:
$!
$!	Param.	  Default		Description.
$!	P1	RUN		Mode option:
$!				   RUN		Run server image.
$!				   DETACH	Run server in detached process.
$!				   INSTALL	Install server image and
$!						DECthreads shareables.
$!
$!      P2  -	HTTP_SERVER.LOG	Log file name.  File will default to same
$!				directory as this procedure.  May include
$!				log_level by appending /{level}
$!
$!      P3  -   HTTP_SERVER.CONF Configuration file name.  This file is also
$!				known as the rules file.  File will default to
$!				same directory as this procedure.
$!
$!	P4  -    80		TCP port number that server will listen on.
$!
$!	P5  -    		TCP port number that server will listen on
$!				with cache disabled.
$!
$! To start the server under another username (i.e. the WWW server account),
$! from system startup, submit this procedure as a batch job with the
$! appropriate /USERNAME and /PARAMETER qualifiers.
$!
$! Note that if http_server.exe is to be installed with privilege, then you 
$! must also install sys$share:cma$lib_shr.exe, sys$share:cma$open_rtl.exe, 
$! and sys$share:cma$rtl.exe.  Invoking this procedure with a P1 parameter of
$! "INSTALL" will install these images.
$!
$ proc = f$parse(f$environment("PROCEDURE"),,,,"NO_CONCEAL")
$ if P1 .eqs. "" THEN P1 = "RUN"
$ IF P1 .nes. "RUN" THEN GOTO ALT_MODE
$! Define DCL symbols that HTTP_SERVER will read as environment variables.
$!
$ HTTP_CACHE_SIZE = 0			! Entries in small document cache.
$ HTTP_CLIENT_LIMIT = 100		! Max. number of concurent clients.
$ HTTP_LOG_LEVEL = 0			! Level of detail in log file.
$!
$! Make default for default host name, this will work with both UCX and
$! multinet.
$!
$ if f$type(http_default_host) + f$trnlnm("HTTP_DEFAULT_HOST") .eqs. "" 
$ then
$	hname = f$trnlnm("UCX$INET_HOST")
$	if f$locate(".",hname) .ge. f$length(hname) then -
		hname = hname + "." + f$trnlnm("UCX$INET_DOMAIN")
$ 	if hname .nes. "." then -
		write sys$output "Using default host name of ",hname
$	HTTP_DEFAULT_HOST = hname
$ endif
$ if "''http_default_host'" .eqs. "."   ! OK no host name, try for CMU
$ then
$       hname = f$trnlnm("INTERNET_HOST_NAME")
$	if hname .eqs. ""		! try for TWG
$	then
$	    hname = f$trnlnm("ARPANET_HOST_NAME")
$	    if f$locate(".",hname) .ge. f$length(hname) then -
		hname = hname + "." + f$trnlnm("INET_DOMAIN_NAME")
$	    if hname .eqs. "." then hname = "?hostname?"
$	endif
$       write sys$output "Using default host name of ",hname
$       HTTP_DEFAULT_HOST = hname
$ endif
$!
$! Define www_root if not defined.
$!
$ if f$trnlnm("www_root") .eqs. ""
$ then
$    root_dir = f$parse("1.;",proc,,,"NO_CONCEAL,SYNTAX_ONLY") - "][" - "]1.;"
$    root_dir = root_dir + ".]"
$    write sys$output "Defining www_root as ", root_dir
$    define www_root 'root_dir'/trans=(term,conceal)
$ endif
$!
$! Setup command line arguments, Make this procedure name the related file
$! to default it to the same directory.
$!
$ log_level = f$element(1,"/",P2)
$ if log_level .nes. "/" .and. log_level .nes. "" then http_log_level = log_level
$ log_file = f$parse(f$element(0,"/",P2),".LOG",proc)
$ rules_file = f$parse(P3,"HTTP_SAMPLE_HOME.CONF",proc)
$ port = "80"
$ if P4 .nes. "" then port = P4
$!
$! Run server as foreign command, specifying SYS$INPUT as the rules file.
$!
$ httpd = "$" + f$parse(".EXE;",proc) - ";"
$ define/user http_rules_file 'rules_file'
$ httpd 'log_file' sys$input 'port' 'P5' 'P6'
#
# Set trace level to the current value of enviroment variable http_log_level.
# Because second argument is missing, trace data will go to error log file.
#
TraceLevel http_log_level
DNSLookup off
#
# Enable access log, entries will be appended to file access.log
#
AccessLog access.log
#
# Chain to rules file specified by user (http_rules_file is logical name).
#
include http_rules_file
#
$ exit $status
$!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
$! Handle special functions for HTTP_SERVER:
$!	DETACH	create detached process.
$!	INSTALL	Install images.
$ ALT_MODE:
$ if P1 .nes. "RUN" .and. P1 .nes. "DETACH" .and. P1 .nes. "INSTALL"
$ then
$    write sys$output "Invalid P1 parameter, must be RUN, DETACH, or INSTALL"
$    exit 20
$ endif
$!
$ if P1 .eqs. "DETACH"
$ then
$!     outfile = f$parse(f$element(0,"/",P2),"HTTP_SERVER_''P4'.OUT;",proc)
$	outfile = "http_server_detached_''P4'.out"
$!
$!    Start detached process with same quotas as current process.
$!
$     CREATE http_server_detached_'P4'.com
$     OPEN/append comfile http_server_detached_'P4'.com
$     write comfile "$ @''proc' RUN """, P2,""" """,P3,""" """,P4,""" """,P5,"""
$     close comfile
$!
$     sv = f$verify(1)
$     run sys$system:loginout/detach/input=http_server_detached_'P4'.com -
	/output='outfile' -
	/buffer_limit='f$getjpi("0","bytlm")' -
	/file_limit='f$getjpi("0","fillm")' -
	/io_buffered='f$getjpi("0","biolm")' -
	/ast_limit='f$getjpi("0","astlm")' -
	/page_file='f$getjpi("0","pgflquota")' -
	/process_name="HTTP Server"-
	/priority=4
$     sv = f$verify(sv)
$     exit $status
$ else
$   if P1 .eqs. "INSTALL"
$   then
$!
$!      Install http image with privilege needed to listen on privileged
$!	TCP port (UCX), which requires that DECthreads images be installed
$!	also.
$!
$	image = f$parse(".EXE;",proc) - ";"
$	privs = "OPER,PHY_IO"
$	if f$trnlnm("MULTINET") .nes. "" .or. -
	   .not. f$getdvi("UCX$DEVICE","EXISTS") then privs = "SYSPRV,PHY_IO"
$	install replace 'image'/privilege=('privs')
$	if .not. f$file("sys$share:cma$lib_shr.exe","known") then -
	    install replace sys$share:cma$lib_shr.exe
$!
$	if .not. f$file("sys$share:cma$open_rtl.exe","known") then -
	    install replace sys$share:cma$open_rtl.exe
$!
$	if .not. f$file("sys$share:cma$rtl.exe","known") then -
	    install replace sys$share:cma$rtl.exe
$!
$	if f$getsyi("CPU") .ge. 128		! test for alpha
$	then
$	    if .not. f$file("sys$share:cma$open_lib_shr.exe","known") then -
	        install replace sys$share:cma$open_lib_shr.exe
$	endif
$   endif
$ endif
$ exit
$!
